// src/errors.ts
class MuseError extends Error {
  fmt() {
    return this.message;
  }
}

class MuseFileError extends MuseError {
  filePath;
  details;
  constructor(message, filePath, details) {
    super(message);
    this.filePath = filePath;
    this.details = details;
  }
  fmt() {
    return `-- ${this.message} --
File Path: ${this.filePath}
Details: ${this.details}`;
  }
}

class MuseFileNotFoundError extends MuseFileError {
  constructor(filePath, details) {
    super("File not found", filePath);
    this.message = "File not found";
    this.filePath = filePath;
    this.details = details ?? "No additional information.";
  }
}

class CLIError extends MuseError {
}

// src/exports.ts
var DEFAULT_CONTENT_KEY = "content";
export {
  MuseFileNotFoundError,
  MuseFileError,
  MuseError,
  DEFAULT_CONTENT_KEY,
  CLIError
};
